@@ -3,7 +3,7 @@
 #
 # Fsdb.pm
 #
-# Copyright (C) 1991-2020 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1991-2022 by John Heidemann <johnh@isi.edu>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License,
@@ -33,7 +33,7 @@ Fsdb - a flat-text database for shell scripting
 
 
 =cut
-our $VERSION = '2.71';
+our $VERSION = '2.75';
 
 =head1 SYNOPSIS
 
@@ -153,7 +153,8 @@ now the third column, not the second.
 
 =item *
 
-A series of actions are self-documenting (each program records what it does).
+A series of actions are self-documenting
+(the provenance of processsing done to produce each output is recorded in comments).
 
 =over 4
 
@@ -214,7 +215,7 @@ the shell) and look at the output.
 To the best of my knowledge, the original implementation of
 this idea was C</rdb>, a commercial product described in the book
 I<UNIX relational database management: application development in the UNIX environment>
-by Rod Manis, Evan Schaffer, and Robert Jorgensen (and
+by Rod Manis, Evan Schaffer, and Robert Jorgensen (1988 by Prentice Hall, and
 also at the web page L<http://www.rdb.com/>).  Fsdb is an incompatible
 re-implementation of their idea without any accelerated indexing or
 forms support.  (But it's free, and probably has better statistics!).
@@ -235,39 +236,52 @@ L<http://www.isi.edu/~johnh/SOFTWARE/FSDB/index.html>.
 
 =head1 WHAT'S NEW
 
-=head2 2.71, 2020-11-16
-Fix a race condition breaking test suites.
+=head2 2.75, 2022-04-02
+New type specifications in the schema to better support type conversions in python.
 
 =over 4
 
-=item BUG FIX
+=item ENHANCEMENT
 
-Suppress a race condition in L<dbcolmerge> was sometimes throwing the error
-"Fsdb::Support::Freds: ending, but running process: dbmerge:xargs"
-in the dbmerge_0_xargs test case, on exit.
+Add optional type specifications to the schema.
+Types are not used in Perl, but are relevant in Python
+and Go Fsdb bindings.
+Types use a subset of perl pack specifiers:
+c, s, l, q are signed 8, 16, 32, and 64-bit integers,
+f is a float, d is double float,
+a is utf-8 string, and &gt; and &lt; can force big or little endianness.
+The default type for everything is "a", that is, utf-8 strings.
+Thanks to Wes Hardaker for pushing to get this long-desired feature
+out the door; his Python bindings need types. 
 
 =item ENHANCEMENT
 
-L<dbcolcreate> now supports C<--header>.
+L<dbcol>, L<dbcolcreate>, L<dbcolcopylast>, and L<dbcolrename>
+now understand and propagate schema types.
+L<dbsort>, L<dbjoin>, L<dbmerge>, L<dbmerge2>
+and L<dbfilepivot> all take a 
+new option C<-t> to sort by type-inferred comparision, if a type is given.
 
-=item BUG FIX
+=item ENHANCEMENT
 
-Fixed several spelling errors in deprecated programs
-and removed information about the no-longer existing FreeBSD and MacOS ports.
-Thanks to Calvin Ardi for the patch.
+L<dbcolstat>, L<dbmultistats>, and L<dbcolmovingstats>
+now include type information in their output schema.
+(They assumes input variables are floats, not integers.)
 
-=item BUG FIX
+=item ENHANCEMENT
 
-L<dbmerge> now handles --xargs when only one file is provided
-(and passes the file through unchanged).
-It also throws a clean error with --xargs if zero files are provided.
-(To support L<dbmerge>, L<dbcol> now has an internal C<--saveoutput> option.)
-Thanks to Yuri Pradkin for reporting the unhandled corner-case.
+Even more IPv6: the functions in
+L<Fsdb::Support::IPv6> package
+now support strings of hex digits
+as an alternate encoding for IP address
+(and they are already the output of ipv6_fullhex),
+and C<ip_fullhex_to_normal> converts full hex-encoded
+IPv4 or IPv6 addresses to their "normal" form
+(dotted-quad or IPv6 printable format).
 
 =back
 
 
-
 =head1 README CONTENTS
 
 =over 4
@@ -345,13 +359,22 @@ comment lines.  For example:
 	root * 0 0 Root /root /bin/bash
 	# this is a simple database
 
-The header line must be first and begins with C<#h>.
+The header line must be first and begins with C<#fsdb>.
 There are rows (records) and columns (fields),
 just like in a normal database.
 Comment lines begin with C<#>.
 Column names are any string not containing spaces or single quote
 (although it is prudent to keep them alphanumeric with underscore).
 
+Columns can optionally include type anntations
+by following name with :t where t is some type.
+(Types are not used in Perl, but are relevant in Python
+and Go Fsdb bindings.)
+Types use a subset of perl pack specifiers:
+c, s, l, q are signed 8, 16, 32, and 64-bit integers,
+f is a float, d is double float,
+a is utf-8 string, and &gt; and &lt; can force big or little endianness.
+
 By default, columns are delimited by whitespace.  
 With this default configuration, the contents of a field
 cannot contain whitespace.
@@ -801,6 +824,37 @@ Exceptions are L<dbcolneaten>, L<dbcolpercentile>, L<dbmapreduce>,
 L<dbmultistats>, L<dbrowsplituniq>.
 
 
+=head2 STANDARD SORTING OPTIONS
+
+A number of programs do sorting, or depend on defining an ordering
+of rows.  Such programs use these standard sorting options:
+
+=over 4
+
+=item B<-r> or B<--descending>
+
+sort in reverse order (high to low)
+
+=item B<-R> or B<--ascending>
+
+sort in normal order (low to high)
+
+=item B<-t> or B<--type-inferred-sorting>
+
+sort fields by type (numeric or leicographic), automatically
+
+=item B<-n> or B<--numeric>
+
+sort numerically
+
+=item B<-N> or B<--lexical>
+
+sort lexicographically
+
+=back
+
+
+
 =head1 ANOTHER EXAMPLE
 
 Take the raw data in C<DATA/http_bandwidth>,
@@ -1188,7 +1242,8 @@ Christopher Meng,
 Calvin Ardi,
 H. Merijn Brand,
 Lan Wei,
-Hang Guo.
+Hang Guo,
+Wes Hardaker.
 
 Fsdb includes datasets contributed from NIST (F<DATA/nist_zarr13.fsdb>),
 from
@@ -1955,7 +2010,7 @@ All programs are now in perl-5, no more shell scripts or perl-4.
 All programs now have manual pages.
 
 Although this is a major step forward, I still expect
-to rename "fsdb" to "fsdb".
+to rename "jdb" to "fsdb".
 
 =over 4
 
@@ -3080,7 +3135,7 @@ Test suites now skip tests for libraries that are missing.
 
 Removed references to Jdb in the package specification.
 Since the name was changed in 2008, there's no longer a huge
-need for backwards comparability.
+need for backwards compatibility.
 (Suggestion form Petr Šabata.)
 
 =item ENHANCEMENT
@@ -3671,6 +3726,70 @@ Thanks to Yuri Pradkin for reporting the unhandled corner-case.
 
 =back
 
+=head2 2.71, 2020-11-16
+Fix a race condition breaking test suites.
+
+=over 4
+
+=item BUG FIX
+
+Suppress a race condition in L<dbcolmerge> was sometimes throwing the error
+"Fsdb::Support::Freds: ending, but running process: dbmerge:xargs"
+in the dbmerge_0_xargs test case, on exit.
+
+=back
+
+=head2 2.72, 2020-12-01
+A small bug and a packaging improvement.
+
+=over 4
+
+=item BUG FIX
+
+L<dbcolhisto> now handles the degenerate case where 
+everything has the same value (previously it would throw
+"illegal division by zero").
+
+=item ENHANCEMENT
+
+The spec for Fedora now includes C<make> as BuildRequires,
+something required for Fedora 34.
+
+=back
+
+=head2 2.73, 2021-05-18
+Updates dbcolpercentile with C<--weighted>, and with more ipv6.
+
+=over 4
+
+=item ENHANCEMENT
+
+L<dbcolpercentile> now has a C<--weighted> option.
+
+=item ENHANCEMENT
+
+The new L<Fsdb::Support::IPv6> package includes
+ipv6_normalize, ipv6_zeroize to rewrite ipv6 print addresses
+in IPv6 normal form, with a 0 in each 4-nybble field.
+
+=back
+
+=head2 2.74, 2021-06-23
+More ipv6.
+
+=over 4
+
+=item ENHANCEMENT
+
+L<Fsdb::Support::IPv6> package includes
+ipv6_fullhex to rewrite ipv6 print addresses
+as full, 128-bit hex values.
+
+=back
+
+
+
+
 =head1 AUTHOR
 
 John Heidemann, C<johnh@isi.edu>
@@ -3681,7 +3800,7 @@ bug reports and fixes.
 
 =head1 COPYRIGHT
 
-Fsdb is Copyright (C) 1991-2020 by John Heidemann <johnh@isi.edu>.
+Fsdb is Copyright (C) 1991-2022 by John Heidemann <johnh@isi.edu>.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of version 2 of the GNU General Public License as
